/********************************************************************************
** Form generated from reading UI file 'kmousetoolui.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_KMOUSETOOLUI_H
#define UI_KMOUSETOOLUI_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_KMouseToolUI
{
public:
    QGridLayout *mainLayout;
    QGroupBox *groupBox1;
    QGridLayout *gridLayout;
    QGridLayout *groupBoxLayout;
    QSpacerItem *spacerItem;
    QLabel *dragTimeLabel;
    QSpinBox *movementEdit;
    QSpinBox *dwellTimeEdit;
    QLabel *movementLabel;
    QCheckBox *cbStart;
    QCheckBox *cbDrag;
    QCheckBox *cbStroke;
    QLabel *dwellTimeLabel;
    QSpinBox *dragTimeEdit;
    QCheckBox *cbClick;
    QDialogButtonBox *buttonBoxSettings;
    QHBoxLayout *hboxLayout;
    QLabel *textLabel1;
    QSpacerItem *spacerItem1;
    QPushButton *buttonStartStop;
    QSpacerItem *spacerItem2;
    QDialogButtonBox *buttonBox;

    void setupUi(QWidget *KMouseToolUI)
    {
        if (KMouseToolUI->objectName().isEmpty())
            KMouseToolUI->setObjectName("KMouseToolUI");
        KMouseToolUI->resize(608, 478);
        mainLayout = new QGridLayout(KMouseToolUI);
        mainLayout->setObjectName("mainLayout");
        groupBox1 = new QGroupBox(KMouseToolUI);
        groupBox1->setObjectName("groupBox1");
        gridLayout = new QGridLayout(groupBox1);
        gridLayout->setSpacing(6);
        gridLayout->setObjectName("gridLayout");
        groupBoxLayout = new QGridLayout();
        groupBoxLayout->setSpacing(6);
        groupBoxLayout->setObjectName("groupBoxLayout");
        groupBoxLayout->setContentsMargins(0, 0, 0, 0);
        spacerItem = new QSpacerItem(16, 20, QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Minimum);

        groupBoxLayout->addItem(spacerItem, 0, 0, 1, 1);

        dragTimeLabel = new QLabel(groupBox1);
        dragTimeLabel->setObjectName("dragTimeLabel");

        groupBoxLayout->addWidget(dragTimeLabel, 0, 1, 1, 1);


        gridLayout->addLayout(groupBoxLayout, 3, 0, 1, 1);

        movementEdit = new QSpinBox(groupBox1);
        movementEdit->setObjectName("movementEdit");
        movementEdit->setMinimum(1);
        movementEdit->setMaximum(40);

        gridLayout->addWidget(movementEdit, 0, 1, 1, 1);

        dwellTimeEdit = new QSpinBox(groupBox1);
        dwellTimeEdit->setObjectName("dwellTimeEdit");
        dwellTimeEdit->setMinimum(1);
        dwellTimeEdit->setMaximum(40);
        dwellTimeEdit->setValue(5);

        gridLayout->addWidget(dwellTimeEdit, 1, 1, 1, 1);

        movementLabel = new QLabel(groupBox1);
        movementLabel->setObjectName("movementLabel");

        gridLayout->addWidget(movementLabel, 0, 0, 1, 1);

        cbStart = new QCheckBox(groupBox1);
        cbStart->setObjectName("cbStart");

        gridLayout->addWidget(cbStart, 6, 0, 1, 2);

        cbDrag = new QCheckBox(groupBox1);
        cbDrag->setObjectName("cbDrag");
        cbDrag->setChecked(true);

        gridLayout->addWidget(cbDrag, 2, 0, 1, 2);

        cbStroke = new QCheckBox(groupBox1);
        cbStroke->setObjectName("cbStroke");

        gridLayout->addWidget(cbStroke, 4, 0, 1, 2);

        dwellTimeLabel = new QLabel(groupBox1);
        dwellTimeLabel->setObjectName("dwellTimeLabel");

        gridLayout->addWidget(dwellTimeLabel, 1, 0, 1, 1);

        dragTimeEdit = new QSpinBox(groupBox1);
        dragTimeEdit->setObjectName("dragTimeEdit");
        dragTimeEdit->setMinimum(1);
        dragTimeEdit->setMaximum(40);
        dragTimeEdit->setValue(3);

        gridLayout->addWidget(dragTimeEdit, 3, 1, 1, 1);

        cbClick = new QCheckBox(groupBox1);
        cbClick->setObjectName("cbClick");

        gridLayout->addWidget(cbClick, 5, 0, 1, 2);

        buttonBoxSettings = new QDialogButtonBox(groupBox1);
        buttonBoxSettings->setObjectName("buttonBoxSettings");
        buttonBoxSettings->setStandardButtons(QDialogButtonBox::Apply|QDialogButtonBox::Reset|QDialogButtonBox::RestoreDefaults);

        gridLayout->addWidget(buttonBoxSettings, 7, 0, 1, 2);


        mainLayout->addWidget(groupBox1, 1, 0, 1, 1);

        hboxLayout = new QHBoxLayout();
        hboxLayout->setObjectName("hboxLayout");
        hboxLayout->setContentsMargins(0, 0, 0, 0);
        textLabel1 = new QLabel(KMouseToolUI);
        textLabel1->setObjectName("textLabel1");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Preferred);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(textLabel1->sizePolicy().hasHeightForWidth());
        textLabel1->setSizePolicy(sizePolicy);
        textLabel1->setScaledContents(false);
        textLabel1->setAlignment(Qt::AlignJustify|Qt::AlignVCenter);
        textLabel1->setWordWrap(true);

        hboxLayout->addWidget(textLabel1);

        spacerItem1 = new QSpacerItem(8, 8, QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Minimum);

        hboxLayout->addItem(spacerItem1);

        buttonStartStop = new QPushButton(KMouseToolUI);
        buttonStartStop->setObjectName("buttonStartStop");

        hboxLayout->addWidget(buttonStartStop);


        mainLayout->addLayout(hboxLayout, 0, 0, 1, 1);

        spacerItem2 = new QSpacerItem(20, 30, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        mainLayout->addItem(spacerItem2, 2, 0, 1, 1);

        buttonBox = new QDialogButtonBox(KMouseToolUI);
        buttonBox->setObjectName("buttonBox");
        buttonBox->setStandardButtons(QDialogButtonBox::Close|QDialogButtonBox::Help);

        mainLayout->addWidget(buttonBox, 3, 0, 1, 1);

#if QT_CONFIG(shortcut)
        dragTimeLabel->setBuddy(dragTimeEdit);
        movementLabel->setBuddy(movementEdit);
        dwellTimeLabel->setBuddy(dwellTimeEdit);
#endif // QT_CONFIG(shortcut)

        retranslateUi(KMouseToolUI);
        QObject::connect(cbDrag, &QCheckBox::toggled, dragTimeLabel, &QLabel::setEnabled);

        QMetaObject::connectSlotsByName(KMouseToolUI);
    } // setupUi

    void retranslateUi(QWidget *KMouseToolUI)
    {
        KMouseToolUI->setWindowTitle(tr2i18n("KMouseTool", nullptr));
        groupBox1->setTitle(tr2i18n("Settings", nullptr));
        dragTimeLabel->setText(tr2i18n("&Drag time (1/10 sec):", nullptr));
        movementLabel->setText(tr2i18n("&Minimum movement:", nullptr));
        cbStart->setText(tr2i18n("Start with &desktop session", nullptr));
        cbDrag->setText(tr2i18n("Smar&t drag", nullptr));
        cbStroke->setText(tr2i18n("&Enable strokes", nullptr));
        dwellTimeLabel->setText(tr2i18n("Dwell &time (1/10 sec):", nullptr));
        cbClick->setText(tr2i18n("A&udible click", nullptr));
        textLabel1->setText(tr2i18n("KMouseTool will run as a background application after you close this dialog. To change the settings again, restart KMouseTool or use the system tray.", nullptr));
        buttonStartStop->setText(tr2i18n("&Start", nullptr));
    } // retranslateUi

};

namespace Ui {
    class KMouseToolUI: public Ui_KMouseToolUI {};
} // namespace Ui

QT_END_NAMESPACE

#endif // KMOUSETOOLUI_H

